download\_toolbox.data package
==============================

Submodules
----------

download\_toolbox.data.amsr module
----------------------------------

.. automodule:: download_toolbox.data.amsr
   :members:
   :undoc-members:
   :show-inheritance:

download\_toolbox.data.cds module
---------------------------------

.. automodule:: download_toolbox.data.cds
   :members:
   :undoc-members:
   :show-inheritance:

download\_toolbox.data.esgf module
----------------------------------

.. automodule:: download_toolbox.data.esgf
   :members:
   :undoc-members:
   :show-inheritance:

download\_toolbox.data.osisaf module
------------------------------------

.. automodule:: download_toolbox.data.osisaf
   :members:
   :undoc-members:
   :show-inheritance:

download\_toolbox.data.utils module
-----------------------------------

.. automodule:: download_toolbox.data.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: download_toolbox.data
   :members:
   :undoc-members:
   :show-inheritance:
